pub fn literal_instance_shape_symbol() -> SymbolExpand description
The symbol of the shape matching individual complex literals, derived from
literal_class_symbol.
pub fn literal_instance_shape_symbol() -> SymbolThe symbol of the shape matching individual complex literals, derived from
literal_class_symbol.